timerelationtools.offset_happens_before_timespan_stops
======================================================

.. autofunction:: abjad.tools.timerelationtools.offset_happens_before_timespan_stops.offset_happens_before_timespan_stops
   :noindex:
